<?php
class PDOClass
{
    /*
    **  用于临时储存请求的错误信息。
    */
    public static $ErrorMsg;

    /*
    **  pdo对象。
    */
    private $pdo;

    /*
    **  用于判断是否当前请求数据库的操作是在测试模式下；
    **  在测试模式下才抛出错误。
    */
    private $isDebug = true;

    /*
    **  PDO的构造函数。
    **  请在下方将
    **  dbname=换成你的数据库名称
    **  $user=数据库用户名
    **  $pass=数据库密码
    */
    function __construct()
    {
        $dsn = "mysql:host=localhost;dbname=vcndevcenter;charset=utf8";
        $user = "root";
        $pass = "123456";
        $this->pdo = new PDO($dsn,$user,$pass);
        $this->pdo->query("set names 'utf8'");
    }

    /*
    **  发送非查询的query请求。
    **  参数一：待执行的sql命令（值需要使用占位符?）
    **  参数二：array结构的值。
    */
    function 发送请求($sqlstr,$args)
    {
        $st = $this->pdo->prepare($sqlstr);
        for ($i=0;$i<count($args);$i++)
        {
            $st->bindValue($i+1,$args[$i]);
        }
        $result = $st->execute();
        $this->setErrorInfo($st->errorInfo());
        return $result;
    }

    /*
    **  发送非查询的query请求。
    **  参数一：待执行的sql命令（值需要使用占位符?）
    **  参数二：array结构的值。
    */
    function 执行删除语句($sqlstr,$args)
    {
        $st = $this->pdo->prepare($sqlstr);
        for ($i=0;$i<count($args);$i++)
        {
            $st->bindValue($i+1,$args[$i]);
        }
        $st->execute();
        $this->setErrorInfo($st->errorInfo());
        $lastId = $st->rowCount();
        return $lastId;
    }

    /*
    **  发送update更新数据的请求。
    **  参数一：待执行的sql命令（值需要使用占位符?）
    **  参数二：array结构的值。
    */
    function 执行更新语句($sqlstr,$args)
    {
        $st = $this->pdo->prepare($sqlstr);
        for ($i=0;$i<count($args);$i++)
        {
            $st->bindValue($i+1,$args[$i]);
        }
        $st->execute();
        $this->setErrorInfo($st->errorInfo());
        $lastId = $st->rowCount();
        return $lastId;
    }

    /*
    **  发送insert（添加数据）请求。
    **  参数一：待执行的sql命令（值需要使用占位符?）
    **  参数二：array结构的值。
    */
    function 执行添加语句($sqlstr,$args)
    {
        $st = $this->pdo->prepare($sqlstr);
        for ($i=0;$i<count($args);$i++)
        {
            $st->bindValue($i+1,$args[$i]);
        }
        $st->execute();
        $this->setErrorInfo($st->errorInfo());
        $lastId = $this->pdo->lastInsertId();
        return $lastId;
    }


    /*
    **  获取执行命令时候发生的错误。
    **  为了安全起见；请最好在debug（测试）的时候才输出信息。
    **  注意:默认为真。
    */
    function 取错误信息()
    {
        if ($this->isDebug)
            return self::$Error;
        else
            return "Not is debug mode.";
    }

    /*
    **  将错误信息存到静态变量中。
    */
    function setError($errorInfo)
    {
        self::$ErrorMsg = json_encode(array("ErrorCode"=> $errorInfo[0],"ErrorMsg" => $errorInfo[2]));
    }


    /*
    **  发送查询的请求。
    **  参数一：待执行的sql命令（值需要使用占位符?）
    **  参数二：array结构的值。
    */
    function 查询数据取一行($sqlstr,$pars)
    {
        $st = $this->pdo->prepare($sqlstr);
        for ($i=0;$i<count($pars);$i++)
        {
            $st->bindValue($i+1,$pars[$i]);
        }
        $st->execute();
        $errMsg = $st->errorInfo();
        $this->setErrorInfo($errMsg);
        $result = $st->fetchAll();
        if (count($result) > 0)
            return $result[0];
        else
            return null;
    }

    /*
    **  查询全部数据。
    */
    function 查询数据($sqlstr)
    {
        $st = $this->pdo->prepare($sqlstr);
        $st->execute();
        return $st->fetchAll();
    }

}